@@ -327,7 +327,7 @@ class TextComp(Component):
         self.font_url = json_data['font_url']
         self.font_size = json_data['fontSize']
         #fontsize px need to convert to pt
-        self.font_size = int(math.ceil(float(self.font_size)*3.0/4.0))
+        # self.font_size = int(math.ceil(float(self.font_size)*3.0/4.0))
         self.bg_color = json_data['backgroundColor']
         if self.bg_color is None or self.bg_color == "":
             self.bg_color="transparent"
@@ -339,8 +339,8 @@ class TextComp(Component):
     def get_clip(self):
         self.font_path = cache_file(self.font_url)
         rs = TextClip(txt= self.text, font = self.font_path.replace("\\","/"), fontsize=self.font_size, color=self.color,
-                        bg_color = self.bg_color, size=(self.position['width'], self.position['height']),
-                        stroke_color = self.stroke_color, stroke_width=self.stroke_width)
+                        bg_color = self.bg_color, size=(int(self.position['width']), int(self.position['height'])+10),
+                        stroke_color = self.stroke_color, stroke_width=self.stroke_width, method='caption', align='center')
         return rs
 
 
