@@ -14,7 +14,7 @@ def create_source_can_loop(dir_path, clip_path, is_delete = True, ext = "mp4" ):
         if dir_path.endswith("/"):
             dir_path = dir_path[:-1]
         clip = VideoFileClip(clip_path,audio=False)
-        tmp_clip_path_z = dir_path + "/" + str(uuid.uuid4()) + '-' + os.path.basename(clip_path)
+        tmp_clip_path_z = os.path.join(dir_path, str(uuid.uuid4()) + '-' + os.path.basename(clip_path))
         clip.write_videofile(tmp_clip_path_z, fps=24, codec='libx264')
         clip.close()
         clip = VideoFileClip(tmp_clip_path_z, audio=False)
@@ -22,10 +22,8 @@ def create_source_can_loop(dir_path, clip_path, is_delete = True, ext = "mp4" ):
         if cross > 3:
             cross=3
         clip = make_loopable.make_loopable(clip, cross)
-        tmp_clip_path_z = dir_path + "/" + str(uuid.uuid4()) + '-' + \
-                                  os.path.basename(clip_path).split(".")[0] + "." + ext
-        tmp_clip_path_z_resync = dir_path + "/" + str(uuid.uuid4()) + '-re-sync-' + \
-                                  os.path.basename(clip_path).split(".")[0] + "." + ext
+        tmp_clip_path_z = os.path.join(dir_path, str(uuid.uuid4()) + '-' + os.path.basename(clip_path).split(".")[0] + "." + ext)
+        tmp_clip_path_z_resync = os.path.join(dir_path , str(uuid.uuid4()) + '-re-sync-' + os.path.basename(clip_path).split(".")[0] + "." + ext)
         try:
             clip.write_videofile(tmp_clip_path_z, fps=24, codec='libx264')
             clip.close()
@@ -50,13 +48,13 @@ def create_source_can_loop(dir_path, clip_path, is_delete = True, ext = "mp4" ):
 
 def create_loop_audio_times(audio_path, times, is_del=True):
     try:
-        tmp_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-' + os.path.basename(audio_path)
+        tmp_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-' + os.path.basename(audio_path))
         shutil.copyfile(audio_path, tmp_clip_path)
-        file_merg_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4())
-        final_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final-' + os.path.basename(audio_path)
+        file_merg_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()))
+        final_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-final-' + os.path.basename(audio_path))
         file_merg = open(file_merg_path, "a")
         for i in range(times):
-            file_merg.write("file '%s'\n" % os.path.basename(tmp_clip_path))
+            file_merg.write("file '%s'\n" % tmp_clip_path)
         file_merg.close()
         cmd = "ffmpeg -y -f concat -safe 0 -i \"%s\" -codec copy \"%s\"" % (file_merg_path, final_clip_path)
         os.system(cmd)
@@ -76,14 +74,14 @@ def create_loop_audio(audio_path, loop_duration):
         audio_clip.close()
         if clip_duration > loop_duration:
             return audio_path
-        tmp_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-' + os.path.basename(audio_path)
+        tmp_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-' + os.path.basename(audio_path))
         shutil.copyfile(audio_path, tmp_clip_path)
         times = int(math.ceil(loop_duration / clip_duration))
-        file_merg_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4())
-        final_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final-' + os.path.basename(audio_path)
+        file_merg_path = os.path.join(get_dir('coolbg_ffmpeg') , str(uuid.uuid4()))
+        final_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-final-' + os.path.basename(audio_path))
         file_merg = open(file_merg_path, "a")
         for i in range(times):
-            file_merg.write("file '%s'\n" % os.path.basename(tmp_clip_path))
+            file_merg.write("file '%s'\n" % tmp_clip_path)
         file_merg.close()
         cmd = "ffmpeg -y -f concat -safe 0 -i \"%s\" -codec copy \"%s\"" % (file_merg_path, final_clip_path)
         os.system(cmd)
@@ -99,21 +97,21 @@ def create_loop_audio(audio_path, loop_duration):
         pass
     return None
 def add_null_sound(input):
-    output=  get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-' + os.path.basename(input)
-    cmd = f"ffmpeg -f lavfi -i anullsrc -i {input} -c:v copy -b:a 128000 -ar 44100 -c:a mp3 -map 0:a -map 1:v -shortest {output}"
+    output=  os.path.join(get_dir('coolbg_ffmpeg') ,str(uuid.uuid4()) + '-' + os.path.basename(input))
+    cmd = f"ffmpeg -f lavfi -i anullsrc -i \"{input}\" -c:v copy -b:a 128000 -ar 44100 -c:a mp3 -map 0:a -map 1:v -shortest \"{output}\""
     os.system(cmd)
     return output
 def merge_list_video(vids, is_del=True):
-    file_merg_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4())
-    final_clip_path = get_dir('results') + str(uuid.uuid4()) + '-final-' + os.path.basename(vids[0])
+    file_merg_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()))
+    final_clip_path = os.path.join(get_dir('results') , str(uuid.uuid4()) + '-final-' + os.path.basename(vids[0]))
     file_merg = open(file_merg_path, "a")
     arrtmp = []
     for vid in vids:
-        tmp_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-' + os.path.basename(vid)
+        tmp_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-' + os.path.basename(vid))
         shutil.copyfile(vid, tmp_clip_path)
         if is_del:
             os.remove(vid)
-        file_merg.write("file '%s'\n" % os.path.basename(tmp_clip_path))
+        file_merg.write("file '%s'\n" % tmp_clip_path)
         arrtmp.append(tmp_clip_path)
     file_merg.close()
     cmd = "ffmpeg -y -f concat -safe 0 -i \"%s\" -codec copy \"%s\"" % (file_merg_path, final_clip_path)
@@ -144,8 +142,8 @@ def create_video_audio(clip_path, audio_path, rs_path=None, is_del=True):
     try:
         tmp_clip_path_z=rs_path
         if tmp_clip_path_z is None:
-            tmp_clip_path_z = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final.mp4'
-        cmd = f"ffmpeg -i {clip_path} -i {audio_path} -vcodec copy -acodec copy -map 0:v -map 1:a -shortest -flags global_header -y {tmp_clip_path_z}"
+            tmp_clip_path_z = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-final.mp4')
+        cmd = f"ffmpeg -i \"{clip_path}\" -i \"{audio_path}\" -vcodec copy -acodec copy -map 0:v -map 1:a -shortest -flags global_header -y \"{tmp_clip_path_z}\""
         os.system(cmd)
         if is_del:
             os.remove(clip_path)
@@ -155,8 +153,8 @@ def create_video_audio(clip_path, audio_path, rs_path=None, is_del=True):
         pass
     return tmp_clip_path_z
 def convert_gif(video_path, is_del=True):
-    tmp_clip_path_z = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-gif.avi'
-    cmd=f"ffmpeg -i {video_path}  -r 24 -c:v ffv1 {tmp_clip_path_z}"
+    tmp_clip_path_z = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-gif.avi')
+    cmd=f"ffmpeg -i \"{video_path}\"  -r 24 -c:v ffv1 \"{tmp_clip_path_z}\""
     os.system(cmd)
     if is_del:
         os.remove(video_path)
@@ -169,7 +167,7 @@ def create_loop(clip_path, loop_duration, can_loopable = True):
                 if clip.duration > loop_duration:
                     return clip_path
                 clip = make_loopable.make_loopable(clip, 0.5)
-                tmp_clip_path_z = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-' + os.path.basename(clip_path)
+                tmp_clip_path_z = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-' + os.path.basename(clip_path))
                 #tmp_clip_path_z_resync = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-re-sync-' + os.path.basename(clip_path).split(".")[0]+".avi"
                 clip.write_videofile(tmp_clip_path_z, fps=clip.fps, codec='libx264')
                 clip.close()
@@ -181,7 +179,7 @@ def create_loop(clip_path, loop_duration, can_loopable = True):
             except:
                 pass
         else:
-            tmp_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-' + os.path.basename(clip_path)
+            tmp_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-' + os.path.basename(clip_path))
             shutil.copyfile(clip_path, tmp_clip_path)
 
         clip_duration = clip.duration
@@ -190,11 +188,11 @@ def create_loop(clip_path, loop_duration, can_loopable = True):
             return clip_path
         times = int(math.ceil(loop_duration / math.floor(clip_duration)))
         # print(times)
-        file_merg_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4())
-        final_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final-' + os.path.basename(clip_path)
+        file_merg_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()))
+        final_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-final-' + os.path.basename(clip_path))
         file_merg = open(file_merg_path, "a")
         for i in range(times):
-            file_merg.write("file '%s'\n" % os.path.basename(tmp_clip_path))
+            file_merg.write("file '%s'\n" % tmp_clip_path)
         file_merg.close()
         cmd = "ffmpeg -y -f concat -safe 0 -i \"%s\" -codec copy \"%s\"" % (file_merg_path, final_clip_path)
         os.system(cmd)
